==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/extendedoptionsplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/extendedoptionsplugin/extendedoptions.png
  0x0,0x0,0x3,0x92,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x3,0x59,0x49,0x44,0x41,0x54,0x78,0xda,0x7d,0x53,0x6b,0x4c,0x93,0x57,
  0x18,0x7e,0xce,0x47,0xef,0x7e,0x40,0x59,0x2b,0x52,0x85,0x52,0x29,0xde,0x36,0x20,
  0x2,0x23,0x38,0x9d,0xb7,0x2c,0x36,0x3a,0x34,0x44,0x8c,0x25,0x2e,0x43,0xe6,0xa2,
  0x41,0xc3,0x66,0x74,0xf8,0x3,0x16,0xaf,0xb3,0xa8,0xd9,0xe2,0xbc,0x4,0xdd,0x60,
  0x46,0x82,0x6e,0x4c,0xbc,0xd4,0x18,0x65,0x46,0x88,0x2e,0xce,0xcb,0x46,0x84,0x4d,
  0x86,0xa3,0x73,0xb5,0xb1,0x14,0x90,0x12,0x56,0x2c,0x50,0x7b,0xef,0x77,0xfc,0xfa,
  0x19,0x13,0x2f,0x89,0x27,0x39,0x39,0x27,0x6f,0x9e,0xf7,0xf2,0xbc,0xef,0xf3,0x12,
  0xbc,0x72,0x8a,0x2f,0xb8,0xa,0x95,0x8,0xd7,0x11,0xe,0x89,0xf,0xfc,0x48,0xe2,
  0x4d,0x34,0x5d,0x86,0x41,0xca,0x10,0xbb,0x1b,0x31,0x1b,0x9b,0xa,0x55,0x17,0x5f,
  0xc4,0x93,0x57,0x3,0xac,0xf8,0xf9,0xd1,0xa5,0x6d,0x45,0x9a,0x2,0xca,0xff,0x4d,
  0x4d,0x8e,0xfe,0xa8,0x6d,0x6b,0xb1,0x76,0x52,0x14,0x68,0x32,0xf,0x34,0x9f,0x5d,
  0x35,0x71,0xe9,0x6b,0x1,0xe6,0x9e,0x18,0xc8,0xf7,0xb9,0x46,0xf7,0x7b,0x82,0x5e,
  0xb3,0x42,0x2c,0x37,0x1e,0x2f,0x9f,0x96,0x1f,0xb5,0x7b,0x83,0xcf,0x40,0xa,0xc9,
  0xb3,0xf7,0xd3,0x23,0xf7,0xdb,0xbc,0x21,0xdf,0x69,0x56,0xa2,0x28,0x92,0xab,0xe2,
  0x2a,0x6e,0xac,0xd6,0xb4,0x91,0x9c,0x63,0xe,0x89,0x32,0x14,0xf8,0xef,0x8b,0x65,
  0xe9,0xa9,0x4e,0x37,0x7,0x25,0xcb,0x20,0x86,0x1,0xf6,0x9d,0xe9,0xc6,0xd8,0xc8,
  0x8,0x38,0xca,0x21,0x36,0x5e,0x89,0x2a,0xe3,0x3b,0xe0,0x38,0xc0,0xed,0xe1,0x90,
  0xa4,0x64,0xf0,0xed,0xc5,0x7,0x3d,0x6e,0xb1,0x74,0x2a,0xc9,0xa8,0xb1,0xa6,0xa5,
  0x88,0x89,0xad,0xca,0xa8,0x47,0x9c,0x2,0xb8,0xda,0xe9,0xc7,0x77,0x8d,0xad,0x88,
  0x4,0x3c,0xe0,0x22,0x61,0x20,0x7a,0x41,0xc1,0x48,0x15,0xd8,0x50,0x5a,0x8,0xc3,
  0x4c,0x39,0x46,0xbd,0xc0,0xde,0xd3,0x36,0xf4,0x86,0xa8,0x5e,0xa0,0xa0,0xaf,0x6a,
  0x5e,0x34,0x2f,0x27,0xbb,0xc5,0x90,0xab,0x81,0xa9,0xb1,0x53,0x70,0x16,0x28,0xf4,
  0x59,0x84,0x57,0xaa,0x4e,0xe6,0x3,0x45,0xc0,0xc8,0x58,0xec,0x5c,0x3b,0x1f,0x2d,
  0x1d,0x3,0xf8,0xed,0xcf,0xbf,0xc,0xb6,0xbd,0x5,0xad,0x44,0xb7,0xf9,0xcc,0xee,
  0xf0,0xf0,0xd0,0x92,0xf5,0x6b,0x4b,0x72,0x5d,0x63,0x41,0xdc,0xb6,0x38,0x31,0x68,
  0xbd,0xb,0x2e,0xe0,0x85,0xa3,0x7e,0x9d,0x90,0x40,0xbb,0xe6,0x87,0x68,0x4f,0xc1,
  0xea,0x66,0x62,0x41,0xb6,0x16,0xc9,0x2a,0x16,0x47,0xeb,0x1a,0x3a,0x44,0x6f,0x8d,
  0xbf,0x4c,0xde,0xdb,0xff,0xf,0xad,0x2c,0x7e,0x1b,0x11,0x9e,0xdf,0x95,0xf6,0x41,
  0xdc,0xec,0x76,0xc2,0xef,0xb4,0xc2,0x56,0xb3,0xf2,0xa5,0x9,0xe9,0x37,0x9e,0xa3,
  0x22,0x56,0x85,0xd9,0xd9,0x53,0xb1,0x34,0x4f,0x3,0x91,0x88,0xef,0x53,0x53,0x37,
  0x48,0x86,0xa9,0x93,0xee,0xf8,0x28,0xb,0x1,0x9e,0xaa,0xa5,0x6f,0x14,0xcd,0x6d,
  0x3d,0x70,0xdd,0xbb,0x86,0xde,0x9f,0x36,0xbd,0x14,0x40,0x57,0xf6,0x23,0x8d,0xd5,
  0x66,0x62,0xf1,0xbb,0x29,0xc8,0xd2,0x25,0x40,0x26,0x6,0x76,0x35,0xfe,0xd,0xa2,
  0xf9,0xe4,0xd0,0x6e,0xdf,0xc3,0xae,0x25,0x1f,0x96,0x6d,0xcf,0x9d,0x97,0x31,0x11,
  0xed,0xd6,0x21,0x98,0xf,0xef,0x44,0xdc,0xf4,0xb9,0xb0,0xd7,0x7e,0x4c,0x9e,0x3b,
  0x7b,0x1d,0x9d,0x58,0xbe,0xae,0x2,0x39,0x53,0xd4,0xb8,0xde,0xf5,0x8,0xbf,0xd4,
  0x7e,0xd5,0x21,0x9f,0x9c,0x79,0x59,0x0,0xc4,0x19,0x3e,0x5b,0x94,0x3c,0xa7,0xb4,
  0x65,0x8b,0x31,0x17,0x22,0x42,0x60,0xbe,0x6d,0xc7,0xf5,0xfa,0x6a,0xc4,0xa6,0xb,
  0x72,0x80,0xc7,0xde,0x81,0xf,0xd6,0x54,0x62,0xe5,0xfb,0xa9,0xf0,0x7,0xa3,0xa5,
  0xb7,0xa3,0xef,0x56,0x83,0x61,0xb4,0xa5,0xa6,0x95,0xa8,0x57,0x55,0xa7,0x49,0x39,
  0xb1,0x6d,0xeb,0x97,0x9b,0x4,0xb0,0x44,0x22,0xc2,0x84,0x78,0x82,0x7b,0x76,0x1f,
  0x2c,0x8e,0x61,0xc1,0x96,0x95,0xa6,0x42,0x66,0xaa,0xc,0xce,0xc7,0x51,0x71,0x45,
  0x40,0x79,0x6d,0x98,0xf6,0x1c,0x44,0x80,0x9,0xe9,0x49,0x62,0xc9,0xd7,0x12,0x32,
  0xe6,0xb1,0x2e,0x2f,0x2d,0xd7,0xf6,0xba,0x9e,0xc0,0xcf,0x37,0x63,0x7e,0x96,0x6,
  0xd3,0x27,0xb1,0x48,0x4c,0x0,0x78,0x4d,0x61,0x68,0x4,0xb8,0xdf,0xef,0xc5,0xb5,
  0xbb,0xfd,0x90,0xf2,0x9,0x52,0xd4,0xe3,0x70,0xbe,0xe1,0x88,0x83,0xc6,0xb2,0x53,
  0x4,0xa,0x9a,0xb2,0xef,0xf3,0xfd,0xf,0x2d,0xdf,0x84,0xbd,0xc3,0xff,0x33,0x21,
  0xae,0xd0,0x50,0x5e,0xcd,0x8,0xa5,0xfb,0xc2,0xfc,0x74,0x28,0x12,0x58,0x9,0x42,
  0x11,0x8a,0xab,0x47,0x2b,0xc1,0x49,0x65,0xa7,0x44,0xf2,0xf8,0x24,0x99,0x6e,0x46,
  0xd5,0x40,0xdd,0xfa,0x3f,0x5e,0x5b,0xa6,0xe4,0x92,0x9a,0xae,0xbc,0x85,0x5,0x19,
  0x41,0xde,0xf1,0xce,0xf9,0x5a,0x44,0xf5,0x9b,0x57,0xb4,0x1,0x92,0x18,0x82,0x3b,
  0xbf,0x5e,0xfa,0xb7,0xef,0xe4,0xe7,0x33,0xde,0xb8,0x8d,0xa9,0x15,0x67,0x17,0x50,
  0xf7,0xe3,0x7a,0xea,0x7f,0xa2,0xa3,0x4a,0xe5,0x2c,0x1,0xe4,0x76,0xff,0xe,0x46,
  0x4c,0x18,0xf5,0xf8,0x15,0x3d,0x7,0x8c,0xe6,0x17,0xf1,0x4f,0x1,0x0,0x2d,0x56,
  0x10,0xfe,0x51,0x28,0x8a,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
  0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // extendedoptions.png
  0x0,0x13,
  0x2,0xd5,0xb3,0x7,
  0x0,0x65,
  0x0,0x78,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,0x64,0x0,0x65,0x0,0x64,0x0,0x6f,0x0,0x70,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,0x2e,0x0,0x70,
  0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons/extendedoptions.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/extendedoptionsplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/extendedoptionsplugin/extendedoptions.png
  0x0,0x0,0x3,0x92,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x3,0x59,0x49,0x44,0x41,0x54,0x78,0xda,0x7d,0x53,0x6b,0x4c,0x93,0x57,
  0x18,0x7e,0xce,0x47,0xef,0x7e,0x40,0x59,0x2b,0x52,0x85,0x52,0x29,0xde,0x36,0x20,
  0x2,0x23,0x38,0x9d,0xb7,0x2c,0x36,0x3a,0x34,0x44,0x8c,0x25,0x2e,0x43,0xe6,0xa2,
  0x41,0xc3,0x66,0x74,0xf8,0x3,0x16,0xaf,0xb3,0xa8,0xd9,0xe2,0xbc,0x4,0xdd,0x60,
  0x46,0x82,0x6e,0x4c,0xbc,0xd4,0x18,0x65,0x46,0x88,0x2e,0xce,0xcb,0x46,0x84,0x4d,
  0x86,0xa3,0x73,0xb5,0xb1,0x14,0x90,0x12,0x56,0x2c,0x50,0x7b,0xef,0x77,0xfc,0xfa,
  0x19,0x13,0x2f,0x89,0x27,0x39,0x39,0x27,0x6f,0x9e,0xf7,0xf2,0xbc,0xef,0xf3,0x12,
  0xbc,0x72,0x8a,0x2f,0xb8,0xa,0x95,0x8,0xd7,0x11,0xe,0x89,0xf,0xfc,0x48,0xe2,
  0x4d,0x34,0x5d,0x86,0x41,0xca,0x10,0xbb,0x1b,0x31,0x1b,0x9b,0xa,0x55,0x17,0x5f,
  0xc4,0x93,0x57,0x3,0xac,0xf8,0xf9,0xd1,0xa5,0x6d,0x45,0x9a,0x2,0xca,0xff,0x4d,
  0x4d,0x8e,0xfe,0xa8,0x6d,0x6b,0xb1,0x76,0x52,0x14,0x68,0x32,0xf,0x34,0x9f,0x5d,
  0x35,0x71,0xe9,0x6b,0x1,0xe6,0x9e,0x18,0xc8,0xf7,0xb9,0x46,0xf7,0x7b,0x82,0x5e,
  0xb3,0x42,0x2c,0x37,0x1e,0x2f,0x9f,0x96,0x1f,0xb5,0x7b,0x83,0xcf,0x40,0xa,0xc9,
  0xb3,0xf7,0xd3,0x23,0xf7,0xdb,0xbc,0x21,0xdf,0x69,0x56,0xa2,0x28,0x92,0xab,0xe2,
  0x2a,0x6e,0xac,0xd6,0xb4,0x91,0x9c,0x63,0xe,0x89,0x32,0x14,0xf8,0xef,0x8b,0x65,
  0xe9,0xa9,0x4e,0x37,0x7,0x25,0xcb,0x20,0x86,0x1,0xf6,0x9d,0xe9,0xc6,0xd8,0xc8,
  0x8,0x38,0xca,0x21,0x36,0x5e,0x89,0x2a,0xe3,0x3b,0xe0,0x38,0xc0,0xed,0xe1,0x90,
  0xa4,0x64,0xf0,0xed,0xc5,0x7,0x3d,0x6e,0xb1,0x74,0x2a,0xc9,0xa8,0xb1,0xa6,0xa5,
  0x88,0x89,0xad,0xca,0xa8,0x47,0x9c,0x2,0xb8,0xda,0xe9,0xc7,0x77,0x8d,0xad,0x88,
  0x4,0x3c,0xe0,0x22,0x61,0x20,0x7a,0x41,0xc1,0x48,0x15,0xd8,0x50,0x5a,0x8,0xc3,
  0x4c,0x39,0x46,0xbd,0xc0,0xde,0xd3,0x36,0xf4,0x86,0xa8,0x5e,0xa0,0xa0,0xaf,0x6a,
  0x5e,0x34,0x2f,0x27,0xbb,0xc5,0x90,0xab,0x81,0xa9,0xb1,0x53,0x70,0x16,0x28,0xf4,
  0x59,0x84,0x57,0xaa,0x4e,0xe6,0x3,0x45,0xc0,0xc8,0x58,0xec,0x5c,0x3b,0x1f,0x2d,
  0x1d,0x3,0xf8,0xed,0xcf,0xbf,0xc,0xb6,0xbd,0x5,0xad,0x44,0xb7,0xf9,0xcc,0xee,
  0xf0,0xf0,0xd0,0x92,0xf5,0x6b,0x4b,0x72,0x5d,0x63,0x41,0xdc,0xb6,0x38,0x31,0x68,
  0xbd,0xb,0x2e,0xe0,0x85,0xa3,0x7e,0x9d,0x90,0x40,0xbb,0xe6,0x87,0x68,0x4f,0xc1,
  0xea,0x66,0x62,0x41,0xb6,0x16,0xc9,0x2a,0x16,0x47,0xeb,0x1a,0x3a,0x44,0x6f,0x8d,
  0xbf,0x4c,0xde,0xdb,0xff,0xf,0xad,0x2c,0x7e,0x1b,0x11,0x9e,0xdf,0x95,0xf6,0x41,
  0xdc,0xec,0x76,0xc2,0xef,0xb4,0xc2,0x56,0xb3,0xf2,0xa5,0x9,0xe9,0x37,0x9e,0xa3,
  0x22,0x56,0x85,0xd9,0xd9,0x53,0xb1,0x34,0x4f,0x3,0x91,0x88,0xef,0x53,0x53,0x37,
  0x48,0x86,0xa9,0x93,0xee,0xf8,0x28,0xb,0x1,0x9e,0xaa,0xa5,0x6f,0x14,0xcd,0x6d,
  0x3d,0x70,0xdd,0xbb,0x86,0xde,0x9f,0x36,0xbd,0x14,0x40,0x57,0xf6,0x23,0x8d,0xd5,
  0x66,0x62,0xf1,0xbb,0x29,0xc8,0xd2,0x25,0x40,0x26,0x6,0x76,0x35,0xfe,0xd,0xa2,
  0xf9,0xe4,0xd0,0x6e,0xdf,0xc3,0xae,0x25,0x1f,0x96,0x6d,0xcf,0x9d,0x97,0x31,0x11,
  0xed,0xd6,0x21,0x98,0xf,0xef,0x44,0xdc,0xf4,0xb9,0xb0,0xd7,0x7e,0x4c,0x9e,0x3b,
  0x7b,0x1d,0x9d,0x58,0xbe,0xae,0x2,0x39,0x53,0xd4,0xb8,0xde,0xf5,0x8,0xbf,0xd4,
  0x7e,0xd5,0x21,0x9f,0x9c,0x79,0x59,0x0,0xc4,0x19,0x3e,0x5b,0x94,0x3c,0xa7,0xb4,
  0x65,0x8b,0x31,0x17,0x22,0x42,0x60,0xbe,0x6d,0xc7,0xf5,0xfa,0x6a,0xc4,0xa6,0xb,
  0x72,0x80,0xc7,0xde,0x81,0xf,0xd6,0x54,0x62,0xe5,0xfb,0xa9,0xf0,0x7,0xa3,0xa5,
  0xb7,0xa3,0xef,0x56,0x83,0x61,0xb4,0xa5,0xa6,0x95,0xa8,0x57,0x55,0xa7,0x49,0x39,
  0xb1,0x6d,0xeb,0x97,0x9b,0x4,0xb0,0x44,0x22,0xc2,0x84,0x78,0x82,0x7b,0x76,0x1f,
  0x2c,0x8e,0x61,0xc1,0x96,0x95,0xa6,0x42,0x66,0xaa,0xc,0xce,0xc7,0x51,0x71,0x45,
  0x40,0x79,0x6d,0x98,0xf6,0x1c,0x44,0x80,0x9,0xe9,0x49,0x62,0xc9,0xd7,0x12,0x32,
  0xe6,0xb1,0x2e,0x2f,0x2d,0xd7,0xf6,0xba,0x9e,0xc0,0xcf,0x37,0x63,0x7e,0x96,0x6,
  0xd3,0x27,0xb1,0x48,0x4c,0x0,0x78,0x4d,0x61,0x68,0x4,0xb8,0xdf,0xef,0xc5,0xb5,
  0xbb,0xfd,0x90,0xf2,0x9,0x52,0xd4,0xe3,0x70,0xbe,0xe1,0x88,0x83,0xc6,0xb2,0x53,
  0x4,0xa,0x9a,0xb2,0xef,0xf3,0xfd,0xf,0x2d,0xdf,0x84,0xbd,0xc3,0xff,0x33,0x21,
  0xae,0xd0,0x50,0x5e,0xcd,0x8,0xa5,0xfb,0xc2,0xfc,0x74,0x28,0x12,0x58,0x9,0x42,
  0x11,0x8a,0xab,0x47,0x2b,0xc1,0x49,0x65,0xa7,0x44,0xf2,0xf8,0x24,0x99,0x6e,0x46,
  0xd5,0x40,0xdd,0xfa,0x3f,0x5e,0x5b,0xa6,0xe4,0x92,0x9a,0xae,0xbc,0x85,0x5,0x19,
  0x41,0xde,0xf1,0xce,0xf9,0x5a,0x44,0xf5,0x9b,0x57,0xb4,0x1,0x92,0x18,0x82,0x3b,
  0xbf,0x5e,0xfa,0xb7,0xef,0xe4,0xe7,0x33,0xde,0xb8,0x8d,0xa9,0x15,0x67,0x17,0x50,
  0xf7,0xe3,0x7a,0xea,0x7f,0xa2,0xa3,0x4a,0xe5,0x2c,0x1,0xe4,0x76,0xff,0xe,0x46,
  0x4c,0x18,0xf5,0xf8,0x15,0x3d,0x7,0x8c,0xe6,0x17,0xf1,0x4f,0x1,0x0,0x2d,0x56,
  0x10,0xfe,0x51,0x28,0x8a,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
  0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // extendedoptions.png
  0x0,0x13,
  0x2,0xd5,0xb3,0x7,
  0x0,0x65,
  0x0,0x78,0x0,0x74,0x0,0x65,0x0,0x6e,0x0,0x64,0x0,0x65,0x0,0x64,0x0,0x6f,0x0,0x70,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,0x2e,0x0,0x70,
  0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons/extendedoptions.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}
